@@ -275,8 +275,11 @@ get_localized_name (const gchar *str)
 static G_CONST_RETURN gchar*
 gail_image_get_name (AtkObject *accessible)
 {
-  if (accessible->name)
-    return accessible->name;
+  G_CONST_RETURN gchar *name;
+
+  name = ATK_OBJECT_CLASS (parent_class)->get_name (accessible); 
+  if (name)
+    return name;
   else
     {
       GtkWidget* widget = GTK_ACCESSIBLE (accessible)->widget;
